#!/usr/bin/env python3
#movies=["The Holy Grail",1975,"Terry Jones & Terry Gilliam",91,["Graham Chapman",["Michael Palin","John Cleese","Terry Gilliam","Eric Idle","Terry Jones"]]]

############## step 1 ########################
#for each_item in movies:
#    if isinstance(each_item,list):
#        for nested_item in each_item:
#            print nested_item
#    else:
#        print each_item

############# step 2 #########################
#for each_item in movies:
#    if isinstance(each_item,list):
#        for nested_item in each_item:
#            if isinstance(nested_item,list):
#                for deeper_item in nested_item:
#                    print deeper_item
#            else:
#                    print nested_item
#    else:  
#        print each_item

############## step 3 ########################
"""This is the "netster.py" module and it provides one function called print_tool()
while prints lists that may or may not include nested list."""

def print_tool(the_list,indent=False,level=0):
    for each_item in the_list:
        if isinstance(each_item,list):
            print_tool(each_item,indent,level+1)
        else:
            if indent:
                for tab_stop in range(level):
                    print("\t", end=' ')
            print(each_item)
